﻿using HogwartsSchool.Entidade;
using HogwartsSchool.Repository;
using System;
using System.Collections.Generic;

class Program
{
    static void Main()
    {
        string connectionString = "Server=localhost;Database=hogwarts;User=root;Password=;";

        ProfessorRepository professorRepo = new ProfessorRepository(connectionString);
        DisciplinaRepository disciplinaRepo = new DisciplinaRepository(connectionString);
        CasaRepository casaRepo = new CasaRepository(connectionString);

        while (true)
        {
            Console.Clear();
            Console.WriteLine("===== Menu Principal =====");
            Console.WriteLine("1. Professores");
            Console.WriteLine("2. Alunos");
            Console.WriteLine("3. Casas");
            Console.WriteLine("4. Disciplinas");
            Console.WriteLine("5. Sair");
            Console.Write("Escolha uma opção: ");

            string opcaoPrincipal = Console.ReadLine();
            switch (opcaoPrincipal)
            {
                case "1":
                    MenuProfessores(professorRepo);
                    break;
                case "2":
                    MenuAlunos();
                    break;
                case "3":
                    MenuCasas(casaRepo);
                    break;
                case "4":
                    MenuDisciplinas(disciplinaRepo);
                    break;
                case "5":
                    Console.WriteLine("Saindo...");
                    return;
                default:
                    Console.WriteLine("Opção inválida! Pressione Enter para continuar...");
                    Console.ReadLine();
                    break;
            }
        }
    }

    // ==============================
    //        MENU PROFESSORES
    // ==============================
    static void MenuProfessores(ProfessorRepository professorRepo)
    {
        while (true)
        {
            Console.Clear();
            Console.WriteLine("===== Menu de Professores =====");
            Console.WriteLine("1. Listar");
            Console.WriteLine("2. Inserir");
            Console.WriteLine("3. Atualizar");
            Console.WriteLine("4. Remover");
            Console.WriteLine("5. Voltar");
            Console.Write("Escolha uma opção: ");

            string opcao = Console.ReadLine();
            switch (opcao)
            {
                case "1":
                    ListarProfessores(professorRepo);
                    break;
                case "2":
                    InserirProfessor(professorRepo);
                    break;
                case "3":
                    AtualizarProfessor(professorRepo);
                    break;
                case "4":
                    RemoverProfessor(professorRepo);
                    break;
                case "5":
                    return;
                default:
                    Console.WriteLine("Opção inválida! Pressione Enter para continuar...");
                    Console.ReadLine();
                    break;
            }
        }
    }

    static void ListarProfessores(ProfessorRepository professorRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Lista de Professores =====");
        List<Professor> professores = professorRepo.ObterTodosProfessores();
        foreach (var professor in professores)
        {
            Console.WriteLine($"ID: {professor.IdProfessor}, Nome: {professor.Nome}");
        }
        Console.WriteLine("\nPressione Enter para voltar...");
        Console.ReadLine();
    }

    static void InserirProfessor(ProfessorRepository professorRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Inserir Professor =====");
        Console.Write("Digite o nome do professor: ");
        string nome = Console.ReadLine();

        int linhas = professorRepo.InserirProfessor(new Professor { Nome = nome });

        if (linhas > 0)
            Console.WriteLine("Professor inserido com sucesso! Pressione Enter para voltar...");
        else 
            Console.WriteLine("Nenhum registro foi inserido...");

        Console.ReadLine();
    }

    static void AtualizarProfessor(ProfessorRepository professorRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Atualizar Professor =====");
        Console.Write("Digite o ID do professor: ");
        int id = Convert.ToInt32(Console.ReadLine());
        Console.Write("Digite o novo nome do professor: ");
        string novoNome = Console.ReadLine();

        int linhas = professorRepo.AtualizarProfessor(new Professor { IdProfessor = id, Nome = novoNome });

        if (linhas > 0)
            Console.WriteLine("Professor atualizado com sucesso! Pressione Enter para voltar...");
        else
            Console.WriteLine("Não houve atualização...");

        Console.ReadLine();
    }

    static void RemoverProfessor(ProfessorRepository professorRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Remover Professor =====");
        Console.Write("Digite o ID do professor a ser removido: ");
        int id = Convert.ToInt32(Console.ReadLine());

        int linhas = professorRepo.RemoverProfessor(id);

        if (linhas > 0)
            Console.WriteLine("Professor removido com sucesso! Pressione Enter para voltar...");
        else
            Console.WriteLine("Não houve remoção...");
        Console.ReadLine();
    }

    // ==============================
    //        MENU DISCIPLINAS
    // ==============================
    static void MenuDisciplinas(DisciplinaRepository disciplinaRepo)
    {
        while (true)
        {
            Console.Clear();
            Console.WriteLine("===== Menu de Disciplinas =====");
            Console.WriteLine("1. Listar");
            Console.WriteLine("2. Inserir");
            Console.WriteLine("3. Atualizar");
            Console.WriteLine("4. Remover");
            Console.WriteLine("5. Voltar");
            Console.Write("Escolha uma opção: ");

            string opcao = Console.ReadLine();
            switch (opcao)
            {
                case "1":
                    ListarDisciplinas(disciplinaRepo);
                    break;
                case "2":
                    InserirDisciplina(disciplinaRepo);
                    break;
                case "3":
                    AtualizarDisciplina(disciplinaRepo);
                    break;
                case "4":
                    RemoverDisciplina(disciplinaRepo);
                    break;
                case "5":
                    return;
                default:
                    Console.WriteLine("Opção inválida! Pressione Enter para continuar...");
                    Console.ReadLine();
                    break;
            }
        }
    }

    static void ListarDisciplinas(DisciplinaRepository disciplinaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Lista de Disciplinas =====");
        List<Disciplina> disciplinas = disciplinaRepo.ObterTodasDisciplinas();
        foreach (var disciplina in disciplinas)
        {
            Console.WriteLine($"ID: {disciplina.IdDisciplina}, Nome: {disciplina.Nome}, Descrição: {disciplina.Descricao}");
        }
        Console.WriteLine("\nPressione Enter para voltar...");
        Console.ReadLine();
    }

    static void InserirDisciplina(DisciplinaRepository disciplinaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Inserir Disciplina =====");
        Console.Write("Digite o nome da disciplina: ");
        string nome = Console.ReadLine();
        Console.Write("Digite a descrição da disciplina: ");
        string descricao = Console.ReadLine();

        int linhas = disciplinaRepo.InserirDisciplina(new Disciplina { Nome = nome, Descricao = descricao });

        if (linhas > 0)
            Console.WriteLine("Disciplina inserida com sucesso! Pressione Enter para voltar...");
        else
            Console.WriteLine("Não houve inserção...");
        Console.ReadLine();
    }

    static void AtualizarDisciplina(DisciplinaRepository disciplinaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Atualizar Disciplina =====");
        Console.Write("Digite o ID da disciplina: ");
        int id = Convert.ToInt32(Console.ReadLine());
        Console.Write("Digite o novo nome da disciplina: ");
        string novoNome = Console.ReadLine();
        Console.Write("Digite a nova descrição da disciplina: ");
        string novaDescricao = Console.ReadLine();

        int linhas = disciplinaRepo.AtualizarDisciplina(new Disciplina { IdDisciplina = id, Nome = novoNome, Descricao = novaDescricao });

        if (linhas > 0)
            Console.WriteLine("Disciplina atualizada com sucesso! Pressione Enter para voltar...");
        else
            Console.WriteLine("Não houve atualização...");

        Console.ReadLine();
    }

    static void RemoverDisciplina(DisciplinaRepository disciplinaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Remover Disciplina =====");
        Console.Write("Digite o ID da disciplina a ser removida: ");
        int id = Convert.ToInt32(Console.ReadLine());

        int linhas = disciplinaRepo.RemoverDisciplina(id);

        if (linhas > 0)
            Console.WriteLine("Disciplina removida com sucesso! Pressione Enter para voltar...");
        else
            Console.WriteLine("Não houve remoção...");

        Console.ReadLine();
    }

    // ==============================
    //        MENU ALUNOS
    // ==============================
    static void MenuAlunos()
    {
        Console.Clear();
        Console.WriteLine("===== Menu de Alunos =====");
        Console.WriteLine("1. Listar");
        Console.WriteLine("2. Inserir");
        Console.WriteLine("3. Atualizar");
        Console.WriteLine("4. Remover");
        Console.WriteLine("5. Voltar");
        Console.WriteLine("\n>>> Implementação pendente para os alunos! <<<\n");
        Console.WriteLine("Pressione Enter para voltar...");
        Console.ReadLine();
    }

    // ==============================
    //        MENU CASAS
    // ==============================
    static void MenuCasas(CasaRepository casaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Menu de Casas =====");
        Console.WriteLine("1. Listar");
        Console.WriteLine("2. Voltar");
        string opcao = Console.ReadLine();
        switch (opcao)
        {
            case "1":
                ListarCasa(casaRepo);
                break;
            case "2":
                return;
            default:
                Console.WriteLine("Opção inválida! Pressione Enter para continuar...");
                Console.ReadLine();
                break;
        }
    }

    static void ListarCasa(CasaRepository casaRepo)
    {
        Console.Clear();
        Console.WriteLine("===== Lista de Disciplinas =====");
        List<Casa> casas = casaRepo.ObterTodasCasas();
        foreach (var casa in casas)        {
            Console.WriteLine($"ID: {casa.IdCasa}, Nome: {casa.Nome}");
        }
        Console.WriteLine("\nPressione Enter para voltar...");
        Console.ReadLine();
    }

}
