﻿using HogwartsSchool.Entidade;
using MySql.Data.MySqlClient;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HogwartsSchool.Repository
{
    internal class DisciplinaRepository
    {
        private readonly string _connectionString;

        public DisciplinaRepository(string connectionString)
        {
            _connectionString = connectionString;
        }

        public List<Disciplina> ObterTodasDisciplinas()
        {
            List<Disciplina> disciplinas = new List<Disciplina>();
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "SELECT * FROM disciplina";
                using (var command = new MySqlCommand(query, connection))
                using (var reader = command.ExecuteReader())
                {
                    while (reader.Read())
                    {
                        disciplinas.Add(new Disciplina
                        {
                            IdDisciplina = reader.GetInt32("id_disciplina"),
                            Nome = reader.GetString("nome"),
                            Descricao = reader.GetString("descricao")
                        });
                    }
                }
            }
            return disciplinas;
        }

        public int InserirDisciplina(Disciplina disciplina)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "INSERT INTO disciplina (nome, descricao) VALUES (@nome, @descricao)";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@nome", disciplina.Nome);
                    command.Parameters.AddWithValue("@descricao", disciplina.Descricao);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }

        public int AtualizarDisciplina(Disciplina disciplina)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "UPDATE disciplina SET nome = @nome, descricao = @descricao WHERE id_disciplina = @idDisciplina";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@nome", disciplina.Nome);
                    command.Parameters.AddWithValue("@descricao", disciplina.Descricao);
                    command.Parameters.AddWithValue("@idDisciplina", disciplina.IdDisciplina);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }

        public int RemoverDisciplina(int idDisciplina)
        {
            int affectedRows = -1;
            using (var connection = new MySqlConnection(_connectionString))
            {
                connection.Open();
                string query = "DELETE FROM disciplina WHERE id_disciplina = @idDisciplina";
                using (var command = new MySqlCommand(query, connection))
                {
                    command.Parameters.AddWithValue("@idDisciplina", idDisciplina);
                    affectedRows = command.ExecuteNonQuery();
                }
            }
            return affectedRows;
        }
    }
}
